@@ -1,17 +1,21 @@
 # --
 # Kernel/Language/en_CA.pm - provides en_CA language translation
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: en_CA.pm,v 1.6 2010/01/13 09:34:22 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
-
 package Kernel::Language::en_CA;
 
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.6 $) [1];
+
 sub Data {
     my $Self = shift;
 
@@ -75,23 +79,13 @@ sub Data {
         'History::Misc' => '%s',
         'History::SetPendingTime' => 'Updated: %s',
         'History::StateUpdate' => 'Old: "%s" New: "%s"',
-        'History::TicketDynamicFieldUpdate' => 'Updated: %s=%s;%s=%s;',
+        'History::TicketFreeTextUpdate' => 'Updated: %s=%s;%s=%s;',
         'History::WebRequestCustomer' => 'Customer request via web.',
         'History::TicketLinkAdd' => 'Added link to ticket "%s".',
         'History::TicketLinkDelete' => 'Deleted link to ticket "%s".',
         'History::Subscribe' => 'Added subscription for user "%s".',
         'History::Unsubscribe' => 'Removed subscription for user "%s".',
         'History::SystemRequest' => 'System Request (%s).',
-        'History::EscalationResponseTimeNotifyBefore' => 'Escalation response time forewarned',
-        'History::EscalationUpdateTimeNotifyBefore' => 'Escalation update time forewarned',
-        'History::EscalationSolutionTimeNotifyBefore' => 'Escalation solution time forewarned',
-        'History::EscalationResponseTimeStart' => 'Escalation response time in effect',
-        'History::EscalationUpdateTimeStart' => 'Escalation update time in effect',
-        'History::EscalationSolutionTimeStart' => 'Escalation solution time in effect',
-        'History::EscalationResponseTimeStop' => 'Escalation response time finished',
-        'History::EscalationUpdateTimeStop' => 'Escalation update time finished',
-        'History::EscalationSolutionTimeStop' => 'Escalation solution time finished',
-        'History::ArchiveFlagUpdate' => 'Archive state changed: "%s"',
         # There's a difference between May (short) and May (long) in some languages, not in en
         'May_long' => 'May',
         #CustomerUser fields
