@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AdminQueue.pm - to add/update/delete queues
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminQueue.pm,v 1.76 2011/01/13 18:07:19 en Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,6 +20,9 @@ use Kernel::System::Salutation;
 use Kernel::System::Signature;
 use Kernel::System::SystemAddress;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.76 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -60,22 +65,13 @@ sub Run {
     );
 
     # get possible sign keys
-    my %KeyList;
-    my %QueueData;
-
+    my %KeyList   = ();
+    my %QueueData = ();
     if ($QueueID) {
-
         %QueueData = $Self->{QueueObject}->QueueGet( ID => $QueueID );
-
-        my $CryptObjectPGP = Kernel::System::Crypt->new(
-            %{$Self},
-            CryptType => 'PGP',
-        );
-
+        my $CryptObjectPGP = Kernel::System::Crypt->new( %{$Self}, CryptType => 'PGP' );
         if ($CryptObjectPGP) {
-
-            my @PrivateKeys = $CryptObjectPGP->PrivateKeySearch( Search => $QueueData{Email} );
-
+            my @PrivateKeys = $CryptObjectPGP->PrivateKeySearch( Search => $QueueData{Email}, );
             for my $DataRef (@PrivateKeys) {
                 $KeyList{"PGP::Inline::$DataRef->{Key}"}
                     = "PGP-Inline: $DataRef->{Key} $DataRef->{Identifier}";
@@ -83,19 +79,12 @@ sub Run {
                     = "PGP-Detached: $DataRef->{Key} $DataRef->{Identifier}";
             }
         }
-
-        my $CryptObjectSMIME = Kernel::System::Crypt->new(
-            %{$Self},
-            CryptType => 'SMIME',
-        );
-
+        my $CryptObjectSMIME = Kernel::System::Crypt->new( %{$Self}, CryptType => 'SMIME' );
         if ($CryptObjectSMIME) {
-
-            my @PrivateKeys = $CryptObjectSMIME->PrivateSearch( Search => $QueueData{Email} );
-
+            my @PrivateKeys = $CryptObjectSMIME->PrivateSearch( Search => $QueueData{Email}, );
             for my $DataRef (@PrivateKeys) {
-                $KeyList{"SMIME::Detached::$DataRef->{Filename}"}
-                    = "SMIME-Detached: $DataRef->{Filename} [$DataRef->{EndDate}] $DataRef->{Email}";
+                $KeyList{"SMIME::Detached::$DataRef->{Hash}"}
+                    = "SMIME-Detached: $DataRef->{Hash} $DataRef->{Email}";
             }
         }
     }
@@ -104,23 +93,20 @@ sub Run {
     # change
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Change' ) {
-
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
-
         $Self->_Edit(
             Action => 'Change',
             %Param,
             %QueueData,
             DefaultSignKeyList => \%KeyList,
         );
-
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminQueue',
             Data         => \%Param,
+
         );
         $Output .= $Self->{LayoutObject}->Footer();
-
         return $Output;
     }
 
@@ -175,19 +161,16 @@ sub Run {
                 %GetParam,
                 UserID => $Self->{UserID}
             );
-
             if ($QueueUpdate) {
 
                 # update preferences
                 my %QueueData = $Self->{QueueObject}->QueueGet( ID => $GetParam{QueueID} );
-
-                my %Preferences;
+                my %Preferences = ();
                 if ( $Self->{ConfigObject}->Get('QueuePreferences') ) {
                     %Preferences = %{ $Self->{ConfigObject}->Get('QueuePreferences') };
                 }
 
                 for my $Item ( sort keys %Preferences ) {
-
                     my $Module = $Preferences{$Item}->{Module}
                         || 'Kernel::Output::HTML::QueuePreferencesGeneric';
 
@@ -200,28 +183,20 @@ sub Run {
                         ConfigItem => $Preferences{$Item},
                         Debug      => $Self->{Debug},
                     );
-
                     my @Params = $Object->Param( QueueData => \%QueueData );
-
                     if (@Params) {
-
-                        my %GetParam;
+                        my %GetParam = ();
                         for my $ParamItem (@Params) {
-
-                            my @Array = $Self->{ParamObject}->GetArray(
-                                Param => $ParamItem->{Name},
-                            );
+                            my @Array
+                                = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
                             $GetParam{ $ParamItem->{Name} } = \@Array;
                         }
-
                         if ( !$Object->Run( GetParam => \%GetParam, QueueData => \%QueueData ) ) {
                             $Note .= $Self->{LayoutObject}->Notify( Info => $Object->Error() );
                         }
                     }
                 }
-
                 $Self->_Overview();
-
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
                 $Output .= $Self->{LayoutObject}->Notify( Info => 'Queue updated!' );
@@ -230,7 +205,6 @@ sub Run {
                     Data         => \%Param,
                 );
                 $Output .= $Self->{LayoutObject}->Footer();
-
                 return $Output;
             }
         }
@@ -239,19 +213,17 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-
         $Self->_Edit(
             Action => 'Change',
             Errors => \%Errors,
             %GetParam,
         );
-
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminQueue',
             Data         => \%Param,
+
         );
         $Output .= $Self->{LayoutObject}->Footer();
-
         return $Output;
 
     }
@@ -260,24 +232,19 @@ sub Run {
     # add
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
-
         my %GetParam;
         $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
-
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
-
         $Self->_Edit(
             Action => 'Add',
             %GetParam,
         );
-
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminQueue',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
-
         return $Output;
     }
 
@@ -297,7 +264,6 @@ sub Run {
 
         # check queue name
         if ( $GetParam{Name} =~ /::/ ) {
-
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
             $Output .= $Self->{LayoutObject}->Warning(
@@ -305,7 +271,6 @@ sub Run {
                 Comment => 'Click back and change it!',
             );
             $Output .= $Self->{LayoutObject}->Footer();
-
             return $Output;
         }
 
@@ -326,40 +291,24 @@ sub Run {
             }
         }
 
-        # check if some fields must be set with default values
-        for my $Optional (
-            qw(UnlockTimeout FirstResponseTime FirstResponseNotify UpdateTime UpdateNotify SolutionTime SolutionNotify FollowUpLock Calendar)
-            )
-        {
-
-            # add default values
-            if ( !$GetParam{$Optional} ) {
-                $GetParam{$Optional} = 0;
-            }
-        }
-
         # if no errors occurred
         if ( !%Errors ) {
 
             # create new queue
-            my $ID = $Self->{QueueObject}->QueueAdd(
+            my $Id = $Self->{QueueObject}->QueueAdd(
                 %GetParam,
                 UserID          => $Self->{UserID},
                 NoDefaultValues => 1,
             );
-
-            if ($ID) {
+            if ($Id) {
 
                 # update preferences
-                my %QueueData = $Self->{QueueObject}->QueueGet( ID => $ID );
-
-                my %Preferences;
+                my %QueueData = $Self->{QueueObject}->QueueGet( ID => $Id );
+                my %Preferences = ();
                 if ( $Self->{ConfigObject}->Get('QueuePreferences') ) {
                     %Preferences = %{ $Self->{ConfigObject}->Get('QueuePreferences') };
                 }
-
-                for my $Item ( sort keys %Preferences ) {
-
+                for my $Item ( keys %Preferences ) {
                     my $Module = $Preferences{$Item}->{Module}
                         || 'Kernel::Output::HTML::QueuePreferencesGeneric';
 
@@ -367,36 +316,34 @@ sub Run {
                     if ( !$Self->{MainObject}->Require($Module) ) {
                         return $Self->{LayoutObject}->FatalError();
                     }
-
                     my $Object = $Module->new(
                         %{$Self},
                         ConfigItem => $Preferences{$Item},
                         Debug      => $Self->{Debug},
                     );
-
                     my @Params = $Object->Param( QueueData => \%QueueData );
-
                     if (@Params) {
-
-                        my %GetParam;
+                        my %GetParam = ();
                         for my $ParamItem (@Params) {
-
-                            my @Array = $Self->{ParamObject}->GetArray(
-                                Param => $ParamItem->{Name},
-                            );
-
+                            my @Array
+                                = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
                             $GetParam{ $ParamItem->{Name} } = \@Array;
                         }
-
                         if ( !$Object->Run( GetParam => \%GetParam, QueueData => \%QueueData ) ) {
                             $Note .= $Self->{LayoutObject}->Notify( Info => $Object->Error() );
                         }
                     }
                 }
-
-                return $Self->{LayoutObject}->Redirect(
-                    OP => "Action=AdminQueueResponses&Subaction=Queue&ID=$ID",
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Queue added!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminQueue',
+                    Data         => \%Param,
                 );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
             }
         }
 
@@ -404,19 +351,17 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-
         $Self->_Edit(
             Action => 'Add',
             Errors => \%Errors,
             %GetParam,
         );
-
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminQueue',
             Data         => \%Param,
+
         );
         $Output .= $Self->{LayoutObject}->Footer();
-
         return $Output;
     }
 
@@ -424,9 +369,7 @@ sub Run {
     # overview
     # ------------------------------------------------------------ #
     else {
-
         $Self->_Overview();
-
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
@@ -434,7 +377,6 @@ sub Run {
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
-
         return $Output;
     }
 }
@@ -446,8 +388,8 @@ sub _Edit {
         Name => 'Overview',
         Data => \%Param,
     );
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+    ${Self}->{LayoutObject}->Block( Name => 'ActionList' );
+    ${Self}->{LayoutObject}->Block( Name => 'ActionOverview' );
 
     # get valid list
     my %ValidList        = $Self->{ValidObject}->ValidList();
@@ -468,10 +410,10 @@ sub _Edit {
                 Valid => 1,
             ),
         },
-        Translation => 0,
-        Name        => 'GroupID',
-        SelectedID  => $Param{GroupID},
-        Class       => 'Validate_Required ' . ( $Param{Errors}->{'GroupIDInvalid'} || '' ),
+        LanguageTranslation => 0,
+        Name                => 'GroupID',
+        SelectedID          => $Param{GroupID},
+        Class               => 'Validate_Required ' . ( $Param{Errors}->{'GroupIDInvalid'} || '' ),
     );
 
     my $ParentQueue = '';
@@ -487,62 +429,26 @@ sub _Edit {
     }
 
     my %Data = $Self->{QueueObject}->QueueList( Valid => 0 );
-
     my $QueueName = '';
-    KEY:
-    for my $Key ( sort keys %Data ) {
-
+    for my $Key ( keys %Data ) {
         if ( $Param{QueueID} && $Param{QueueID} eq $Key ) {
             $QueueName = $Data{ $Param{QueueID} };
-            last KEY;
+            last;
         }
     }
     my %CleanHash = %Data;
-    for my $Key ( sort keys %Data ) {
+    for my $Key ( keys %Data ) {
         if ( $CleanHash{$Key} eq $QueueName || $CleanHash{$Key} =~ /^\Q$QueueName\E\:\:/ ) {
             delete $CleanHash{$Key};
         }
     }
-
-    # get list type
-    my $ListType = $Self->{ConfigObject}->Get('Ticket::Frontend::ListType');
-
-    # get max queue level
-    my $MaxParentLevel = ( $Self->{ConfigObject}->Get('Ticket::Frontend::MaxQueueLevel') || 5 ) - 1;
-
-    # verify if queue list should be a list or a tree
-    if ( $ListType eq 'tree' ) {
-        $Param{QueueOption} = $Self->{LayoutObject}->AgentQueueListOption(
-            Data => { '' => ' -', %CleanHash, },
-            Name => 'ParentQueueID',
-            Selected       => $ParentQueue,
-            MaxLevel       => $MaxParentLevel,
-            OnChangeSubmit => 0,
-        );
-    }
-    else {
-
-    # leave only queues with $MaxQueueLevel levels, because max allowed level is $MaxQueueLevel + 1:
-    # new queue + $MaxQueueLevel levels of parent queue = $MaxQueueLevel + 1 levels
-        for my $Key ( sort keys %CleanHash ) {
-            my $QueueName      = $CleanHash{$Key};
-            my @QueueNameLevel = split( ::, $QueueName );
-            my $QueueLevel     = $#QueueNameLevel + 1;
-            if ( $QueueLevel > $MaxParentLevel ) {
-                delete $CleanHash{$Key};
-            }
-        }
-
-        $Param{QueueOption} = $Self->{LayoutObject}->BuildSelection(
-            Data          => \%CleanHash,
-            Name          => 'ParentQueueID',
-            SelectedValue => $ParentQueue,
-            PossibleNone  => 1,
-            HTMLQuote     => 0,
-            Translation   => 0,
-        );
-    }
-
+    $Param{QueueOption} = $Self->{LayoutObject}->AgentQueueListOption(
+        Data => { '' => ' -', %CleanHash, },
+        Name => 'ParentQueueID',
+        Selected       => $ParentQueue,
+        MaxLevel       => 4,
+        OnChangeSubmit => 0,
+    );
     $Param{QueueLongOption} = $Self->{LayoutObject}->AgentQueueListOption(
         Data => { $Self->{QueueObject}->QueueList( Valid => 0 ), },
         Name => 'QueueID',
@@ -563,31 +469,27 @@ sub _Edit {
     );
     $Param{FirstResponseNotifyOptionStrg} = $Self->{LayoutObject}->BuildSelection(
         Data         => \%NotifyLevelList,
-        Translation  => 0,
         Name         => 'FirstResponseNotify',
         SelectedID   => $Param{FirstResponseNotify},
         PossibleNone => 1,
     );
     $Param{UpdateNotifyOptionStrg} = $Self->{LayoutObject}->BuildSelection(
         Data         => \%NotifyLevelList,
-        Translation  => 0,
         Name         => 'UpdateNotify',
         SelectedID   => $Param{UpdateNotify},
         PossibleNone => 1,
     );
     $Param{SolutionNotifyOptionStrg} = $Self->{LayoutObject}->BuildSelection(
         Data         => \%NotifyLevelList,
-        Translation  => 0,
         Name         => 'SolutionNotify',
         SelectedID   => $Param{SolutionNotify},
         PossibleNone => 1,
     );
     $Param{SignatureOption} = $Self->{LayoutObject}->BuildSelection(
         Data => { $Self->{SignatureObject}->SignatureList( Valid => 1 ), },
-        Translation => 0,
-        Name        => 'SignatureID',
-        SelectedID  => $Param{SignatureID},
-        Class       => 'Validate_Required ' . ( $Param{Errors}->{'SignatureIDInvalid'} || '' ),
+        Name => 'SignatureID',
+        SelectedID => $Param{SignatureID},
+        Class => 'Validate_Required ' . ( $Param{Errors}->{'SignatureIDInvalid'} || '' ),
     );
     $Param{FollowUpLockYesNoOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
@@ -596,15 +498,11 @@ sub _Edit {
     );
 
     $Param{SystemAddressOption} = $Self->{LayoutObject}->BuildSelection(
-        Data => {
-            $Self->{SystemAddressObject}->SystemAddressList( Valid => 1 ),
-        },
-        Translation => 0,
-        Name        => 'SystemAddressID',
-        SelectedID  => $Param{SystemAddressID},
-        PossibleNone => 1,     # to avoid automatic assignments if the current SA is invalid
-        Max          => 200,
-        Class => 'Validate_Required ' . ( $Param{Errors}->{'SystemAddressIDInvalid'} || '' ),
+        Data => { $Self->{SystemAddressObject}->SystemAddressList( Valid => 1 ), },
+        Name => 'SystemAddressID',
+        SelectedID => $Param{SystemAddressID},
+        Max        => 200,
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'SystemAddressIDInvalid'} || '' ),
     );
 
     my %DefaultSignKeyList = ();
@@ -622,10 +520,9 @@ sub _Edit {
     );
     $Param{SalutationOption} = $Self->{LayoutObject}->BuildSelection(
         Data => { $Self->{SalutationObject}->SalutationList( Valid => 1 ), },
-        Translation => 0,
-        Name        => 'SalutationID',
-        SelectedID  => $Param{SalutationID},
-        Class       => 'Validate_Required ' . ( $Param{Errors}->{'SalutationIDInvalid'} || '' ),
+        Name => 'SalutationID',
+        SelectedID => $Param{SalutationID},
+        Class => 'Validate_Required ' . ( $Param{Errors}->{'SalutationIDInvalid'} || '' ),
     );
     $Param{FollowUpOption} = $Self->{LayoutObject}->BuildSelection(
         Data => {
@@ -650,10 +547,9 @@ sub _Edit {
         }
     }
     $Param{CalendarOption} = $Self->{LayoutObject}->BuildSelection(
-        Data        => \%Calendar,
-        Translation => 0,
-        Name        => 'Calendar',
-        SelectedID  => $Param{Calendar},
+        Data       => \%Calendar,
+        Name       => 'Calendar',
+        SelectedID => $Param{Calendar},
     );
 
     $Self->{LayoutObject}->Block(
@@ -680,13 +576,11 @@ sub _Edit {
     }
 
     # show each preferences setting
-    my %Preferences;
+    my %Preferences = ();
     if ( $Self->{ConfigObject}->Get('QueuePreferences') ) {
         %Preferences = %{ $Self->{ConfigObject}->Get('QueuePreferences') };
     }
-
     for my $Item ( sort keys %Preferences ) {
-
         my $Module = $Preferences{$Item}->{Module}
             || 'Kernel::Output::HTML::QueuePreferencesGeneric';
 
@@ -699,21 +593,16 @@ sub _Edit {
             ConfigItem => $Preferences{$Item},
             Debug      => $Self->{Debug},
         );
-
         my @Params = $Object->Param( QueueData => \%Param );
-
         if (@Params) {
-
             for my $ParamItem (@Params) {
-
                 $Self->{LayoutObject}->Block(
                     Name => 'Item',
                     Data => { %Param, },
                 );
-
                 if (
-                    ref $ParamItem->{Data} eq 'HASH'
-                    || ref $Preferences{$Item}->{Data} eq 'HASH'
+                    ref( $ParamItem->{Data} ) eq 'HASH'
+                    || ref( $Preferences{$Item}->{Data} ) eq 'HASH'
                     )
                 {
                     $ParamItem->{'Option'} = $Self->{LayoutObject}->BuildSelection(
@@ -721,7 +610,6 @@ sub _Edit {
                         %{$ParamItem},
                     );
                 }
-
                 $Self->{LayoutObject}->Block(
                     Name => $ParamItem->{Block} || $Preferences{$Item}->{Block} || 'Option',
                     Data => {
@@ -739,7 +627,6 @@ sub _Edit {
             String => $Param{Response},
         );
     }
-
     return 1;
 }
 
@@ -750,52 +637,38 @@ sub _Overview {
         Name => 'Overview',
         Data => \%Param,
     );
-
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionAdd' );
+    ${Self}->{LayoutObject}->Block( Name => 'ActionList' );
+    ${Self}->{LayoutObject}->Block( Name => 'ActionAdd' );
 
     $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
     );
-
-    # get queue list
     my %List = $Self->{QueueObject}->QueueList( Valid => 0 );
 
-    # error handling
-    if ( !%List ) {
+    if (%List) {
 
+        # get valid list
+        my %ValidList = $Self->{ValidObject}->ValidList();
+        for my $QueueID ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+
+            my %Data = $Self->{QueueObject}->QueueGet( ID => $QueueID, );
+            $Data{GroupName} = $Self->{GroupObject}->GroupLookup( GroupID => $Data{GroupID} );
+            $Self->{LayoutObject}->Block(
+                Name => 'OverviewResultRow',
+                Data => {
+                    Valid => $ValidList{ $Data{ValidID} },
+                    %Data,
+                },
+            );
+        }
+    }
+    else {
         $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsg',
-        );
-
-        return 1;
-    }
-
-    # get valid list
-    my %ValidList = $Self->{ValidObject}->ValidList();
-
-    for my $QueueID ( sort { $List{$a} cmp $List{$b} } keys %List ) {
-
-        # get queue data
-        my %Data = $Self->{QueueObject}->QueueGet(
-            ID => $QueueID,
-        );
-
-        # group lookup
-        $Data{GroupName} = $Self->{GroupObject}->GroupLookup(
-            GroupID => $Data{GroupID},
-        );
-
-        $Self->{LayoutObject}->Block(
-            Name => 'OverviewResultRow',
-            Data => {
-                Valid => $ValidList{ $Data{ValidID} },
-                %Data,
-            },
+            Data => {},
         );
     }
-
     return 1;
 }
 
