@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketCompose.pm - to compose and send a message
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketCompose.pm,v 1.114 2010/11/16 11:04:09 mb Exp $
+# $Id: AgentTicketCompose.pm,v 1.124 2011/01/13 18:08:47 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,7 +24,7 @@ use Kernel::System::TemplateGenerator;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.114 $) [1];
+$VERSION = qw($Revision: 1.124 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -91,6 +91,7 @@ sub Run {
     my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
 
     # get lock state
+    my $TicketBackType = 'TicketBack';
     if ( $Self->{Config}->{RequiredLock} ) {
         if ( !$Self->{TicketObject}->TicketLockGet( TicketID => $Self->{TicketID} ) ) {
             $Self->{TicketObject}->TicketLockSet(
@@ -106,19 +107,9 @@ sub Run {
 
             # show lock state
             if ( !$Owner ) {
-                my $Output = $Self->{LayoutObject}->Header(
-                    Value => $Ticket{Number},
-                    Type  => 'Small',
-                );
-                $Output .= $Self->{LayoutObject}->Warning(
-                    Message => 'Ticket locked!',
-                    Comment => 'Please unlock the ticket first.',
-                );
-                $Output .= $Self->{LayoutObject}->Footer(
-                    Type => 'Small',
-                );
-                return $Output;
+                return $Self->{LayoutObject}->FatalError();
             }
+            $TicketBackType .= 'Undo';
         }
         else {
             my $AccessOk = $Self->{TicketObject}->OwnerCheck(
@@ -139,20 +130,8 @@ sub Run {
                 );
                 return $Output;
             }
-            else {
-                $Self->{LayoutObject}->Block(
-                    Name => 'TicketBack',
-                    Data => { %Param, TicketID => $Self->{TicketID}, },
-                );
-            }
         }
     }
-    else {
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketBack',
-            Data => { %Param, %Ticket, },
-        );
-    }
 
     # get params
     my %GetParam;
@@ -365,91 +344,95 @@ sub Run {
             }
         }
 
+        # get free text config options
+        my %TicketFreeText;
+        for my $Count ( 1 .. 16 ) {
+            my $Key  = 'TicketFreeKey' . $Count;
+            my $Text = 'TicketFreeText' . $Count;
+            $TicketFreeText{$Key} = $Self->{TicketObject}->TicketFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Key,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+            $TicketFreeText{$Text} = $Self->{TicketObject}->TicketFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Text,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+
+            # If Key has value 2, this means that the freetextfield is required
+            if ( $Self->{Config}->{TicketFreeText}->{$Count} == 2 ) {
+                $TicketFreeText{Required}->{$Count} = 1;
+            }
+
+            # check required FreeTextField (if configured)
+            if (
+                $Self->{Config}->{TicketFreeText}->{$Count} == 2
+                && $GetParam{$Text} eq ''
+                && $IsUpload == 0
+                )
+            {
+                $TicketFreeText{Error}->{$Count} = 1;
+                $Error{$Text} = 'ServerError';
+            }
+        }
+
+        my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
+            Config => \%TicketFreeText,
+            Ticket => \%GetParam,
+        );
+
+        # ticket free time
+        my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
+            %Param,
+            Ticket => \%GetParam,
+        );
+
+        # article free text
+        my %ArticleFreeText;
+        for my $Count ( 1 .. 3 ) {
+            my $Key  = 'ArticleFreeKey' . $Count;
+            my $Text = 'ArticleFreeText' . $Count;
+            $ArticleFreeText{$Key} = $Self->{TicketObject}->ArticleFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Key,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+            $ArticleFreeText{$Text} = $Self->{TicketObject}->ArticleFreeTextGet(
+                TicketID => $Self->{TicketID},
+                Type     => $Text,
+                Action   => $Self->{Action},
+                UserID   => $Self->{UserID},
+            );
+
+            # If Key has value 2, this means that the field is required
+            if ( $Self->{Config}->{ArticleFreeText}->{$Count} == 2 ) {
+                $ArticleFreeText{Required}->{$Count} = 1;
+            }
+
+            # check required ArticleTextField (if configured)
+            if (
+                $Self->{Config}->{ArticleFreeText}->{$Count} == 2
+                && $GetParam{$Text} eq ''
+                && $IsUpload == 0
+                )
+            {
+                $ArticleFreeText{Error}->{$Count} = 1;
+                $Error{$Text} = 'ServerError';
+            }
+        }
+
+        my %ArticleFreeTextHTML = $Self->{LayoutObject}->TicketArticleFreeText(
+            Config  => \%ArticleFreeText,
+            Article => \%GetParam,
+        );
+
         # check if there is an error
         if (%Error) {
 
-            # get free text config options
-            my %TicketFreeText;
-            for my $Count ( 1 .. 16 ) {
-                my $Key  = 'TicketFreeKey' . $Count;
-                my $Text = 'TicketFreeText' . $Count;
-                $TicketFreeText{$Key} = $Self->{TicketObject}->TicketFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Key,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-                $TicketFreeText{$Text} = $Self->{TicketObject}->TicketFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Text,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-
-                # If Key has value 2, this means that the freetextfield is required
-                if ( $Self->{Config}->{TicketFreeText}->{$Count} == 2 ) {
-                    $TicketFreeText{Required}->{$Count} = 1;
-                }
-
-                # check required FreeTextField (if configured)
-                if (
-                    $Self->{Config}->{TicketFreeText}->{$Count} == 2
-                    && $GetParam{$Text} eq ''
-                    && $IsUpload == 0
-                    )
-                {
-                    $TicketFreeText{Error}->{$Count} = 1;
-                }
-            }
-            my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
-                Config => \%TicketFreeText,
-                Ticket => \%GetParam,
-            );
-
-            # ticket free time
-            my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
-                %Param,
-                Ticket => \%GetParam,
-            );
-
-            # article free text
-            my %ArticleFreeText;
-            for my $Count ( 1 .. 3 ) {
-                my $Key  = 'ArticleFreeKey' . $Count;
-                my $Text = 'ArticleFreeText' . $Count;
-                $ArticleFreeText{$Key} = $Self->{TicketObject}->ArticleFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Key,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-                $ArticleFreeText{$Text} = $Self->{TicketObject}->ArticleFreeTextGet(
-                    TicketID => $Self->{TicketID},
-                    Type     => $Text,
-                    Action   => $Self->{Action},
-                    UserID   => $Self->{UserID},
-                );
-
-                # If Key has value 2, this means that the field is required
-                if ( $Self->{Config}->{ArticleFreeText}->{$Count} == 2 ) {
-                    $ArticleFreeText{Required}->{$Count} = 1;
-                }
-
-                # check required ArticleTextField (if configured)
-                if (
-                    $Self->{Config}->{ArticleFreeText}->{$Count} == 2
-                    && $GetParam{$Text} eq ''
-                    && $IsUpload == 0
-                    )
-                {
-                    $ArticleFreeText{Error}->{$Count} = 1;
-                }
-            }
-
-            my %ArticleFreeTextHTML = $Self->{LayoutObject}->TicketArticleFreeText(
-                Config  => \%ArticleFreeText,
-                Article => \%GetParam,
-            );
             my $Output = $Self->{LayoutObject}->Header(
                 Value => $Ticket{TicketNumber},
                 Type  => 'Small',
@@ -462,6 +445,7 @@ sub Run {
                 Errors         => \%Error,
                 Attachments    => \@Attachments,
                 GetParam       => \%GetParam,
+                TicketBackType => $TicketBackType,
                 %Ticket,
                 %TicketFreeTextHTML,
                 %TicketFreeTimeHTML,
@@ -491,7 +475,7 @@ sub Run {
             Source => 'String',
         );
         if (%UploadStuff) {
-            push( @AttachmentData, \%UploadStuff );
+            push @AttachmentData, \%UploadStuff;
         }
 
         # get recipients
@@ -517,6 +501,12 @@ sub Run {
                     my $ContentIDHTMLQuote = $Self->{LayoutObject}->Ascii2Html(
                         Text => $ContentID,
                     );
+
+                    # workaround for link encode of rich text editor, see bug#5053
+                    my $ContentIDLinkEncode = $Self->{LayoutObject}->LinkEncode($ContentID);
+                    $GetParam{Body} =~ s/(ContentID=)$ContentIDLinkEncode/$1$ContentID/g;
+
+                    # ignore attachment if not linked in body
                     next if $GetParam{Body} !~ /(\Q$ContentIDHTMLQuote\E|\Q$ContentID\E)/i;
                 }
 
@@ -854,6 +844,12 @@ sub Run {
             $Data{ToEmail} = $Email->address();
         }
 
+        # only reply to sender
+        if ( !$GetParam{ReplyAll} ) {
+            $Data{Cc}  = '';
+            $Data{Bcc} = '';
+        }
+
         # use customer database email
         if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ComposeAddCustomerAddress') ) {
 
@@ -871,7 +867,7 @@ sub Run {
                 # add customers database address to Cc
                 else {
                     $Output .= $Self->{LayoutObject}->Notify(
-                        Data => "Cc: ($Data{To}) added database email!",
+                        Data => "Cc: ($Customer{UserEmail}) added database email!",
                     );
                     if ( $Data{Cc} ) {
                         $Data{Cc} .= ', ' . $Customer{UserEmail};
@@ -909,12 +905,6 @@ sub Run {
             }
         }
 
-        # only reply to sender
-        if ( !$GetParam{ReplyAll} ) {
-            $Data{Cc}  = '';
-            $Data{Bcc} = '';
-        }
-
         # get template
         my $TemplateGenerator = Kernel::System::TemplateGenerator->new( %{$Self} );
         my %Response          = $TemplateGenerator->Response(
@@ -1107,6 +1097,9 @@ $QData{"Signature"}
             Article => { %GetParam, %ArticleFreeDefault, },
         );
 
+        # build references if exist
+        my $References = ( $Data{MessageID} || '' ) . ( $Data{References} || '' );
+
         # build view ...
         $Output .= $Self->_Mask(
             TicketID       => $Self->{TicketID},
@@ -1118,8 +1111,9 @@ $QData{"Signature"}
             ReplyArticleID => $GetParam{ArticleID},
             %Ticket,
             %Data,
-            InReplyTo  => $Data{MessageID},
-            References => "$Data{References} $Data{MessageID}",
+            InReplyTo      => $Data{MessageID},
+            References     => "$References",
+            TicketBackType => $TicketBackType,
             %TicketFreeTextHTML,
             %TicketFreeTimeHTML,
             %ArticleFreeTextHTML,
@@ -1204,6 +1198,15 @@ sub _Mask {
         },
     );
 
+    $Self->{LayoutObject}->Block(
+        Name => $Param{TicketBackType},
+        Data => {
+
+            #            FormID => $Self->{FormID},
+            %Param,
+        },
+    );
+
     # run compose modules
     if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' ) {
         my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
@@ -1258,7 +1261,7 @@ sub _Mask {
         $Self->{LayoutObject}->Block(
             Name => 'TicketFreeTime',
             Data => {
-                TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
+                TicketFreeTimeKey => $Param{ 'TicketFreeTimeKey' . $Count },
                 TicketFreeTime    => $Param{ 'TicketFreeTime' . $Count },
                 Count             => $Count,
             },
@@ -1308,8 +1311,22 @@ sub _Mask {
         );
     }
 
+    my $ShownOptionsBlock;
+
     # show spell check
     if ( $Self->{LayoutObject}->{BrowserSpellChecker} ) {
+
+        # check if need to call Options block
+        if ( !$ShownOptionsBlock ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketOptions',
+                Data => {},
+            );
+
+            # set flag to "true" in order to prevent calling the Options block again
+            $ShownOptionsBlock = 1;
+        }
+
         $Self->{LayoutObject}->Block(
             Name => 'SpellCheck',
             Data => {},
@@ -1318,6 +1335,18 @@ sub _Mask {
 
     # show address book
     if ( $Self->{LayoutObject}->{BrowserJavaScriptSupport} ) {
+
+        # check if need to call Options block
+        if ( !$ShownOptionsBlock ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketOptions',
+                Data => {},
+            );
+
+            # set flag to "true" in order to prevent calling the Options block again
+            $ShownOptionsBlock = 1;
+        }
+
         $Self->{LayoutObject}->Block(
             Name => 'AddressBook',
             Data => {},
