@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketCustomer.pm - to set the ticket customer and show the customer history
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: AgentTicketCustomer.pm,v 1.38 2010/08/09 17:40:41 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,7 +15,9 @@ use strict;
 use warnings;
 
 use Kernel::System::CustomerUser;
-use Kernel::System::VariableCheck qw(:all);
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.38 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -88,25 +92,6 @@ sub Run {
         }
     }
 
-    # get ACL restrictions
-    $Self->{TicketObject}->TicketAcl(
-        Data          => '-',
-        TicketID      => $Self->{TicketID},
-        ReturnType    => 'Action',
-        ReturnSubType => '-',
-        UserID        => $Self->{UserID},
-    );
-    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
-
-    # check if ACL restrictions exist
-    if ( IsHashRefWithData( \%AclAction ) ) {
-
-        # show error screen if ACL prohibits this action
-        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
-            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
-        }
-    }
-
     if ( $Self->{Subaction} eq 'Update' ) {
 
         # challenge token check for write action
@@ -125,7 +110,7 @@ sub Run {
             = $Self->{ParamObject}->GetParam( Param => 'SelectedCustomerUser' ) || '';
 
         # use customer login instead of email address if applicable
-        if ( $Param{SelectedCustomerUser} ne '' ) {
+        if ( $Param{SelectedCustomerUser} ne q{} ) {
             $Param{CustomerUserID} = $Param{SelectedCustomerUser};
         }
 
@@ -140,7 +125,7 @@ sub Run {
             # check if just one customer user exists
             # if just one, fillup CustomerUserID and CustomerID
             $Param{CustomerUserListCount} = 0;
-            for my $KeyCustomerUser ( sort keys %CustomerUserList ) {
+            for my $KeyCustomerUser ( keys %CustomerUserList ) {
                 $Param{CustomerUserListCount}++;
                 $Param{CustomerUserListLast}     = $CustomerUserList{$KeyCustomerUser};
                 $Param{CustomerUserListLastUser} = $KeyCustomerUser;
@@ -171,7 +156,7 @@ sub Run {
                 = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $CustomerUserOption, );
             my %CustomerUserList
                 = $Self->{CustomerUserObject}->CustomerSearch( UserLogin => $CustomerUserOption, );
-            for my $KeyCustomerUser ( sort keys %CustomerUserList ) {
+            for my $KeyCustomerUser ( keys %CustomerUserList ) {
                 $Param{CustomerUserID} = $KeyCustomerUser;
             }
             if ( $CustomerUserData{UserCustomerID} ) {
@@ -207,9 +192,7 @@ sub Run {
 
             # redirect
             return $Self->{LayoutObject}->PopupClose(
-                URL =>
-                    $Self->{LastScreenView}
-                    || "Action=AgentTicketZoom;TicketID=$Self->{TicketID}",
+                URL => "Action=AgentTicketZoom;TicketID=$Self->{TicketID}",
             );
         }
         else {
@@ -249,7 +232,8 @@ sub Form {
             Name => 'CustomerSearchAutoComplete',
             Data => {
                 minQueryLength      => $AutoCompleteConfig->{MinQueryLength}      || 2,
-                queryDelay          => $AutoCompleteConfig->{QueryDelay}          || 100,
+                queryDelay          => $AutoCompleteConfig->{QueryDelay}          || 0.1,
+                typeAhead           => $AutoCompleteConfig->{TypeAhead}           || 'false',
                 maxResultsDisplayed => $AutoCompleteConfig->{MaxResultsDisplayed} || 20,
                 ActiveAutoComplete  => $AutoCompleteConfig->{Active},
             },
@@ -258,13 +242,13 @@ sub Form {
         # get ticket data
         my %TicketData = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
         if ( $TicketData{CustomerUserID} || $Param{CustomerUserID} ) {
-            %CustomerUserData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                User => $Param{CustomerUserID} || $TicketData{CustomerUserID},
-            );
+            %CustomerUserData
+                = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $Param{CustomerUserID}
+                    || $TicketData{CustomerUserID},
+                );
         }
         $TicketCustomerID = $TicketData{CustomerID};
-        $Param{SelectedCustomerUser} = $TicketData{CustomerUserID};
-
         $Param{Table} = $Self->{LayoutObject}->AgentCustomerViewTable(
             Data => \%CustomerUserData,
             Max  => $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoComposeMaxSize'),
