@@ -1,6 +1,8 @@
 # --
 # Kernel/Output/HTML/NotificationUIDCheck.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: NotificationUIDCheck.pm,v 1.9 2010/03/28 18:13:13 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +14,9 @@ package Kernel::Output::HTML::NotificationUIDCheck;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.9 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -36,8 +41,7 @@ sub Run {
     return $Self->{LayoutObject}->Notify(
         Priority => 'Error',
         Link     => '$Env{"Baselink"}Action=AdminUser',
-        Data =>
-            '$Text{"Don\'t use the Superuser account to work with OTRS! Create new Agents and work with these accounts instead."}',
+        Data     => '$Text{"Don\'t work with UserID 1 (System account)! Create new users!"}',
     );
 }
 
