@@ -1,6 +1,8 @@
 # --
 # Kernel/System/CustomerUser.pm - some customer user functions
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: CustomerUser.pm,v 1.61 2010/10/04 21:38:21 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,7 +16,8 @@ use warnings;
 
 use Kernel::System::CustomerCompany;
 
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.61 $) [1];
 
 =head1 NAME
 
@@ -116,9 +119,7 @@ sub new {
 
 return customer source list
 
-    my %List = $CustomerUserObject->CustomerSourceList(
-        ReadOnly => 0 # optional, 1 returns only RO backends, 0 returns writable, if not passed returns all backends
-    );
+    my %List = $CustomerUserObject->CustomerSourceList();
 
 =cut
 
@@ -126,20 +127,11 @@ sub CustomerSourceList {
     my ( $Self, %Param ) = @_;
 
     my %Data;
-    SOURCE:
     for my $Count ( '', 1 .. 10 ) {
 
         # next if customer backend is not used
-        next SOURCE if !$Self->{ConfigObject}->Get("CustomerUser$Count");
-        if ( defined $Param{ReadOnly} ) {
-            my $CustomerBackendConfig = $Self->{ConfigObject}->Get("CustomerUser$Count");
-            if ( $Param{ReadOnly} ) {
-                next SOURCE if !$CustomerBackendConfig->{ReadOnly};
-            }
-            else {
-                next SOURCE if $CustomerBackendConfig->{ReadOnly};
-            }
-        }
+        next if !$Self->{ConfigObject}->Get("CustomerUser$Count");
+
         $Data{"CustomerUser$Count"} = $Self->{ConfigObject}->Get("CustomerUser$Count")->{Name}
             || "No Name $Count";
     }
@@ -150,30 +142,21 @@ sub CustomerSourceList {
 
 to search users
 
-    # text search
     my %List = $CustomerUserObject->CustomerSearch(
         Search => '*some*', # also 'hans+huber' possible
         Valid  => 1, # not required, default 1
     );
 
-    # username search
     my %List = $CustomerUserObject->CustomerSearch(
         UserLogin => '*some*',
         Valid     => 1, # not required, default 1
     );
 
-    # email search
     my %List = $CustomerUserObject->CustomerSearch(
         PostMasterSearch => 'email@example.com',
         Valid            => 1, # not required, default 1
     );
 
-    # search by CustomerID
-    my %List = $CustomerUserObject->CustomerSearch(
-        CustomerID       => 'CustomerID123',
-        Valid            => 1, # not required, default 1
-    );
-
 =cut
 
 sub CustomerSearch {
@@ -224,39 +207,6 @@ sub CustomerUserList {
     return %Data;
 }
 
-=item CustomerIDList()
-
-return a list of with all known unique CustomerIDs of the registered customers users (no SearchTerm),
-or a filtered list where the CustomerIDs must contain a search term.
-
-    my @CustomerIDs = $CustomerUserObject->CustomerIDList(
-        SearchTerm  => 'somecustomer',    # optional
-        Valid       => 1,                 # optional
-    );
-
-=cut
-
-sub CustomerIDList {
-    my ( $Self, %Param ) = @_;
-
-    my @Data;
-    for my $Count ( '', 1 .. 10 ) {
-
-        # next if customer backend is not used
-        next if !$Self->{"CustomerUser$Count"};
-
-        # get customer list result of backend and merge it
-        push @Data, $Self->{"CustomerUser$Count"}->CustomerIDList(%Param);
-    }
-
-    # make entries unique
-    my %Tmp;
-    @Tmp{@Data} = undef;
-    @Data = sort { lc $a cmp lc $b } keys %Tmp;
-
-    return @Data;
-}
-
 =item CustomerName()
 
 get customer user name
@@ -324,8 +274,6 @@ get user data (UserLogin, UserFirstname, UserLastname, UserEmail, ...)
 sub CustomerUserDataGet {
     my ( $Self, %Param ) = @_;
 
-    return if !$Param{User};
-
     for my $Count ( '', 1 .. 10 ) {
 
         # next if customer backend is not used
@@ -338,7 +286,7 @@ sub CustomerUserDataGet {
         # add preferences defaults
         my $Config = $Self->{ConfigObject}->Get('CustomerPreferencesGroups');
         if ($Config) {
-            for my $Key ( sort keys %{$Config} ) {
+            for my $Key ( keys %{$Config} ) {
 
                 # next if no default data exists
                 next if !defined $Config->{$Key}->{DataSelected};
@@ -412,7 +360,6 @@ sub CustomerUserAdd {
             return;
         }
     }
-
     return $Self->{ $Param{Source} }->CustomerUserAdd(%Param);
 }
 
@@ -444,7 +391,7 @@ sub CustomerUserUpdate {
     }
 
     # check for UserLogin-renaming and if new UserLogin already exists...
-    if ( $Param{ID} && ( lc $Param{UserLogin} ne lc $Param{ID} ) ) {
+    if ( $Param{ID} && ( $Param{UserLogin} ne $Param{ID} ) ) {
         my %User = $Self->CustomerUserDataGet( User => $Param{UserLogin} );
         if (%User) {
             $Self->{LogObject}->Log(
@@ -630,7 +577,6 @@ sub SearchPreferences {
         }
         %Data = ( %SubData, %Data );
     }
-
     return %Data;
 }
 
@@ -653,16 +599,16 @@ sub TokenGenerate {
         return;
     }
 
-    # the list of characters that can appear in a randomly generated token
+    # The list of characters that can appear in a randomly generated token.
     my @Chars = ( 0 .. 9, 'A' .. 'Z', 'a' .. 'z' );
 
-    # the number of characters in the list
+    # The number of characters in the list.
     my $CharsLen = scalar @Chars;
 
-    # generate the token
+    # Generate the token.
     my $Token = 'C';
     for ( my $i = 0; $i < 14; $i++ ) {
-        $Token .= $Chars[ rand $CharsLen ];
+        $Token .= $Chars[ rand($CharsLen) ];
     }
 
     # save token in preferences
@@ -672,6 +618,7 @@ sub TokenGenerate {
         UserID => $Param{UserID},
     );
 
+    # Return the Token.
     return $Token;
 }
 
@@ -701,17 +648,21 @@ sub TokenCheck {
     );
 
     # check requested vs. stored token
-    return if !$Preferences{UserToken};
-    return if $Preferences{UserToken} ne $Param{Token};
+    if ( $Preferences{UserToken} && $Preferences{UserToken} eq $Param{Token} ) {
 
-    # reset password token
-    $Self->SetPreferences(
-        Key    => 'UserToken',
-        Value  => '',
-        UserID => $Param{UserID},
-    );
+        # reset password token
+        $Self->SetPreferences(
+            Key    => 'UserToken',
+            Value  => '',
+            UserID => $Param{UserID},
+        );
 
-    return 1;
+        # return true if token is valid
+        return 1;
+    }
+
+    # return false if token is invalid
+    return;
 }
 
 1;
@@ -727,3 +678,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.61 $ $Date: 2010/10/04 21:38:21 $
+
+=cut
