@@ -1,6 +1,8 @@
 // --
 // Core.UI.Dialog.js - Dialogs
-// Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
+// --
+// $Id: Core.UI.Dialog.js,v 1.31 2011/01/04 11:21:41 mn Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -23,7 +25,7 @@ Core.UI.Dialog = (function (TargetNS) {
     /*
      * check dependencies first
      */
-    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI draggable')) {
+    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI dialog')) {
         return;
     }
     if (!Core.Debug.CheckDependency('Core.UI.Dialog', 'Core.Config', 'Core.Config')) {
@@ -32,30 +34,22 @@ Core.UI.Dialog = (function (TargetNS) {
 
     /**
      * @function
+     * @private
      * @return nothing
      * @description Adjusts the scrollable inner container of the dialog after every resizing.
      */
-    function AdjustScrollableHeight(AllowAutoGrow) {
+    function AdjustScrollableHeight() {
         // Check window height and adjust the scrollable height of InnerContent
         // Calculation:
         // Window height
-        // - top margin of dialog twice (for top and bottom) - only use this for big dialog windows
+        // - top margin of dialog twice (for top and bottom)
         // - some static pixels for Header and Footer of dialog
         var ContentScrollHeight = 0,
             WindowHeight = $(window).height(),
             WindowScrollTop = $(window).scrollTop(),
-            DialogTopMargin = $('.Dialog:visible').offset().top,
-            DialogHeight = $('.Dialog:visible').height();
+            DialogTopMargin = $('.Dialog:visible').offset().top;
 
-        // if dialog height is more than 300px recalculate width of InnerContent to make it scrollable
-        // if dialog is smaller than 300px this is not necessary
-        // if AllowAutoGrow is set, auto-resizing should be possible
-        if (AllowAutoGrow || DialogHeight > 300) {
-            ContentScrollHeight = WindowHeight - ((DialogTopMargin - WindowScrollTop) * 2) - 100;
-        }
-        else {
-            ContentScrollHeight = 200;
-        }
+        ContentScrollHeight = WindowHeight - ((DialogTopMargin - WindowScrollTop) * 2) - 100;
         $('.Dialog:visible .Content .InnerContent').css('max-height', ContentScrollHeight);
     }
 
@@ -143,15 +137,13 @@ Core.UI.Dialog = (function (TargetNS) {
      *               Headline: string (default: undefined) Defines a special headline within the dialog window
      *               Text: string (default: undefined) The text which is outputtet in the dialog window
      *               HTML: string (default: undefined) Used for content dialog windows. Contains a complete HTML snippet or an jQuery object with containing HTML
-     *               PositionTop: value (default: undefined) Defines the top position of the dialog window
-     *               PositionBottom: value (default: undefined) Defines the bottom position of the dialog window
-     *               PositionLeft: value|Center (default: undefined) Defines the left position of the dialog window. Center centers the window
-     *               PositionRight: value (default: undefined) Defines the right position of the dialog window
+     *               PositionTop: value (default: undefined) Defines the top position of the dilaog window
+     *               PositionBottom: value (default: undefined) Defines the bottom position of the dilaog window
+     *               PositionLeft: value|Center (default: undefined) Defines the left position of the dilaog window. Center centers the window
+     *               PositionRight: value (default: undefined) Defines the right position of the dilaog window
      *               CloseOnClickOutside true|false (default: false) If true, clicking outside the dialog closes the dialog
      *               CloseOnEscape true|false (default: false) If true, pressing escape key closes the dialog
      *               NotDraggableIE7: true|false (default: false) If true, the dialog is not draggable in IE7 (due to performance reasons)
-     *               AllowAutoGrow: true|false (default: false) If true, the InnerContent of the dialog can resize until the max window height is reached,
-     *                                                          If false (default), InnerContent of small dialogs does not resize over 200px
      *               Buttons: Array of Hashes with the following properties (buttons are placed in a div "footer" of the dialog):
      *                  Label: string Text of the button
      *                  Type: string 'Submit'|'Close' (default: none) Special type of the button - invokes a standard function
@@ -167,12 +159,6 @@ Core.UI.Dialog = (function (TargetNS) {
         // this invokes the callback and the closing of the dialog
         function HandleClosingAction() {
             var $CloseButton = $('.Dialog:visible button.Close');
-
-            // Hide any possibly existing tooltips.
-            if (Core.Form && Core.Form.ErrorTooltips) {
-                Core.Form.ErrorTooltips.HideTooltip();
-            }
-
             if ($CloseButton.length) {
                 $CloseButton.trigger('click');
             }
@@ -382,20 +368,13 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Check window height and adjust the scrollable height of InnerContent
-        AdjustScrollableHeight(Params.AllowAutoGrow);
+        AdjustScrollableHeight();
 
         // Add event-handling
         if (!(Params.NotDraggableIE7 && $.browser.msie && parseInt($.browser.version, 10) === 7)) {
             $Dialog.draggable({
                 containment: 'body',
-                handle: '.Header',
-                start: function(Event, UI) {
-                    // Hide any possibly existing tooltips as they will not be moved
-                    //  with this dialog.
-                    if (Core.Form && Core.Form.ErrorTooltips) {
-                        Core.Form.ErrorTooltips.HideTooltip();
-                    }
-                }
+                handle: '.Header'
             });
         }
 
@@ -450,8 +429,8 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Add resize event handler for calculating the scroll height
-        $(window).unbind('resize.Dialog').bind('resize.Dialog', function () {
-            AdjustScrollableHeight(Params.AllowAutoGrow);
+        $(window).unbind('resize.Dialog').bind('resize.Dialog', function (event) {
+            AdjustScrollableHeight();
         });
 
         // Init KeyEvent-Logger
@@ -474,7 +453,7 @@ Core.UI.Dialog = (function (TargetNS) {
      * @param NotDraggableIE7 If true, the dialog is not draggable in IE7 (performance reasons)
      * @return nothing
      */
-    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, NotDraggableIE7, AllowAutoGrow) {
+    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, NotDraggableIE7) {
         TargetNS.ShowDialog({
             HTML: HTML,
             Title: Title,
@@ -484,8 +463,7 @@ Core.UI.Dialog = (function (TargetNS) {
             PositionTop: PositionTop,
             PositionLeft: PositionLeft,
             Buttons: Buttons,
-            NotDraggableIE7: NotDraggableIE7,
-            AllowAutoGrow: AllowAutoGrow
+            NotDraggableIE7: NotDraggableIE7
         });
     };
 
@@ -516,6 +494,13 @@ Core.UI.Dialog = (function (TargetNS) {
      * @return nothing
      */
     TargetNS.CloseDialog = function (Object) {
+        function ResetRTE(Editor) {
+            CKEDITOR.instances[Editor].setMode('source');
+            window.setTimeout(function () {
+                CKEDITOR.instances[Editor].setMode('wysiwyg');
+            }, 100);
+        }
+
         var $Dialog, DialogCopy, DialogCopySelector, BackupHTML, Editor;
         $Dialog = $(Object).closest('.Dialog:visible');
 
@@ -550,6 +535,22 @@ Core.UI.Dialog = (function (TargetNS) {
             // write the new DialogCopy back
             Core.Data.Set($('body'), 'DialogCopy', DialogCopy);
         }
+
+        // Repair all existing rich text editors
+        // in Firefox/Linux and IE/Win the editor is not usable anymore after a OTRS dialog was opened
+        // This workaround fixes this, because opening the wysiwyg again reloads the editor.
+        if (typeof CKEDITOR !== 'undefined') {
+            for (Editor in CKEDITOR.instances) {
+                if (typeof CKEDITOR.instances[Editor].setMode === 'function') {
+                    window.setTimeout(ResetRTE, 0, Editor);
+                }
+            }
+        }
+
+        // Workaround for bug#6060 - In IE7, input elements can't get focus anymore after opening dialog
+        // giving focus automatically solves the problem
+        $('input:text:first').focus().blur();
+
     };
 
     return TargetNS;
